@@ -42,7 +42,7 @@ ENAset = R6::R6Class("ENAset",
       rotation.set = NULL,
 
       #center.data = center_data_c,    ### made local to run
-      node.position.method = lws.positions.es,
+      node.position.method = lws.positions.sq,
 
       endpoints.only = T,
 
@@ -535,25 +535,10 @@ ENAset = R6::R6Class("ENAset",
         self = self$function.params$node.position.method(self);
       ###
 
-      ###
-      # Calculate the correlations
-      ###
-      pComb = combn(nrow(self$points.rotated),2)
-      point1 = pComb[1,]
-      point2 = pComb[2,]
-
-      svdDiff = matrix(self$points.rotated[point1,] - self$points.rotated[point2,], ncol=private$dimensions)
-      optDiff = matrix(self$centroids[point1,] - self$centroids[point2,], ncol=private$dimensions)
-
-      self$correlations = as.data.frame(mapply(function(method) {
-        lapply(1:private$dimensions, function(dim) {
-          cor(as.numeric(svdDiff[,dim]), as.numeric(optDiff[,dim]), method=method)
-        });
-      }, c("pearson","spearman")))
-
-
       return(self);
     }
-
+     #####
+     ## END: Private Functions
+     #####
   )
 )
