@@ -43,8 +43,14 @@ ena.group <- function(
     points.dt = data.table::data.table(pts);
     if(is.logical(by)) {
       points.dt.means = points.dt[by, lapply(.SD,method),]; # by=by];
-    } else {
+    } else if(all(by %in% colnames(pts))) {
       points.dt.means = points.dt[, lapply(.SD,method), by=by];
+    } else {
+      points.dt.means = as.data.frame(aggregate(points.dt, by = list(by), FUN = method)) #"mean"))
+      rownames(points.dt.means) = points.dt.means$Group.1
+      points.dt.means = points.dt.means[,colnames(points.dt)]
+      # agg.df[as.vector(unique(group.by)),]u
+      return (points.dt.means[as.vector(unique(by)),]);
     }
     return(as.data.frame(points.dt.means[,colnames(points.dt),with=F]))
   }
